Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(384)

Unified Diff: third_party/WebKit/Source/core/layout/ng/ng_block_node.h

Issue 2721613003: [LayoutNG] Move remaining ng_units structs to their own files (Closed)
Patch Set: Don't export NGBoxStrut for now Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/ng/ng_block_node.h
diff --git a/third_party/WebKit/Source/core/layout/ng/ng_block_node.h b/third_party/WebKit/Source/core/layout/ng/ng_block_node.h
index 04d2311e1beacf9d607584453f08260a4921c2ef..9e1ee7e5ee11d3f965a06b0c55ef106497080078 100644
--- a/third_party/WebKit/Source/core/layout/ng/ng_block_node.h
+++ b/third_party/WebKit/Source/core/layout/ng/ng_block_node.h
@@ -20,7 +20,7 @@ class NGBreakToken;
class NGConstraintSpace;
class NGLayoutResult;
struct NGLogicalOffset;
-struct MinAndMaxContentSizes;
+struct MinMaxContentSize;
// Represents a node to be laid out.
class CORE_EXPORT NGBlockNode final : public NGLayoutInputNode {
@@ -40,12 +40,12 @@ class CORE_EXPORT NGBlockNode final : public NGLayoutInputNode {
LayoutObject* GetLayoutObject() override;
// Computes the value of min-content and max-content for this box.
// If the underlying layout algorithm's ComputeMinAndMaxContentSizes returns
// no value, this function will synthesize these sizes using Layout with
// special constraint spaces -- infinite available size for max content, zero
// available size for min content, and percentage resolution size zero for
// both.
- MinAndMaxContentSizes ComputeMinAndMaxContentSizes();
+ MinMaxContentSize ComputeMinMaxContentSize();
const ComputedStyle& Style() const;

Powered by Google App Engine
@@ -40,12 +40,12 @@ class CORE_EXPORT NGBlockNode final : public NGLayoutInputNode {
LayoutObject* GetLayoutObject() override;
// Computes the value of min-content and max-content for this box.
- // If the underlying layout algorithm's ComputeMinAndMaxContentSizes returns
+ // If the underlying layout algorithm's ComputeMinMaxContentSize returns
// no value, this function will synthesize these sizes using Layout with
// special constraint spaces -- infinite available size for max content, zero
This is Rietveld 408576698